@@ -1018,7 +1018,7 @@ class NumerousAdminClient(NumerousClient):
             ))
 
         if complete:
-            self._base_client.CompleteExecution(
+            self._base_client.CompleteExecutionIgnoreInstance(
                 spm_pb2.ExecutionMessage(project_id=project, scenario_id=scenario, job_id=job,
                                          execution_id=exe))
 
